/**
 * @author    Yannick Deubel (https://github.com/yandeu)
 * @copyright Copyright (c) 2021 Yannick Deubel
 * @license   {@link https://github.com/yandeu/five-server/blob/main/LICENSE LICENSE}
 */
import { PHP_ERROR, PHP_TEMPLATE } from '../public.js';
import { exec } from 'child_process';
import fs from 'fs';
export class ExecPHP {
    get path() {
        return this.php;
    }
    get ini() {
        return this.phpIni;
    }
    set path(path) {
        this.php = path;
    }
    set ini(path) {
        this.phpIni = path;
    }
    async parseFile(absolutePath, res) {
        let msg = '';
        return new Promise(resolve => {
            const returnWithError = (msg, template) => {
                return resolve(template.replace('{msg}', msg));
            };
            if (!this.php) {
                msg = 'Could not find PHP executable.';
                res.status(500);
            }
            if (!msg && this.php && !fs.existsSync(this.php)) {
                msg = `Could not find executable: "${this.php}"`;
                res.status(500);
            }
            if (msg)
                returnWithError(msg, PHP_TEMPLATE);
            const cmd = `"${this.php}" "${absolutePath}"`;
            // https://nodejs.org/docs/latest-v18.x/api/child_process.html#child_processexeccommand-options-callback
            exec(cmd, { maxBuffer: 1024 * 1024 * 2 }, function (error, stdout, stderr) {
                if (error)
                    returnWithError(`<p>error: ${error.message}</p>`, PHP_ERROR);
                if (stderr)
                    returnWithError(`<p>stderr: ${stderr}</p>`, PHP_ERROR);
                resolve(stdout);
            });
        });
    }
}
//# sourceMappingURL=execPHP.js.map